/* Structures for TYPE-3 in C */

typedef unsigned char   Byte;
typedef unsigned int    Word;
typedef unsigned long   Longword;

typedef struct
{
    Word    Zone;       /* Zone address */
    Word    Net;        /* Net address */
    Word    Node;       /* Node address */
    Word    Point;      /* Point address or 0 if boss */
} TAddress;

enum CapabilityWord
{
    Type2   = 0x0001,
    Type3   = 0x0002,
    Type4   = 0x0004,
    Type5   = 0x0008,
    Type6   = 0x0010,
    Type7   = 0x0020,
    Type8   = 0x0040,
    Type9   = 0x0080,
    Type10  = 0x0100,
    Type11  = 0x0200,
    Type12  = 0x0400,
    Type13  = 0x0800,
    Type14  = 0x1000,
    Type15  = 0x2000,
    Type16  = 0x4000,
    RFC822  = 0x8000
};

typedef Longword    TTimeStamp;

enum TMsgFlags
{
    Pvt         = 0x0001,   /* Private message */
    FileAttach  = 0x0002,   /* File attach message */
    FileReq     = 0x0004,   /* File request message */
    UpdReq      = 0x0008,   /* File update request message */
    Direct      = 0x0010,   /* Do not route this message */
    Crash       = 0x0020,   /* High-priority mail */
    Hold        = 0x0040,   /* Hold for pickup */
    IMM         = 0x0080,   /* Immediate mail */
    RRQ         = 0x0100,   /* Return receipt request */
    CRQ         = 0x0200,   /* Confirm receipt request */
    IRR         = 0x0400,   /* Is return receipt */
    Machine     = 0x0800,   /* Message to a program */
    NoForCC     = 0x1000,   /* CC in NetMail, NoForward in EchoMail */
    Permanent   = 0x2000,   /* Message should not be pruged by age */
    reserved14  = 0x4000,   /* Reserved for future extension */
    reserved15  = 0x8000    /* Reserved for future extension */
};

enum TLocalFlags
{
    Local       = 0x0001,   /* Message is created localy */
    InTransit   = 0x0002,   /* Message is not destinated for this system */
    Orphan      = 0x0004,   /* Unknown destination */
    KillSent    = 0x0008,   /* Remove message after it has been sent */
    DelSent     = 0x0010,   /* Delete attached file(s) after have been sent */
    TruncSent   = 0x0020,   /* Truncate attached file(s) after have been sent */
    Sent        = 0x0040,   /* Message has been sent */
    IsRead      = 0x0080,   /* Message has been read by the SysOp */
    Rcvd        = 0x0100,   /* Message has been read by its addressee */
    LockMsg     = 0x0200,   /* Lock the message for further access */
    DontSend    = 0x0400,   /* Do not send the actual message */
    unused11    = 0x0800,   /* Reserved for future extension */
    unused12    = 0x1000,   /* Reserved for future extension */
    unused13    = 0x2000,   /* Reserved for future extension */
    unused14    = 0x4000,   /* Reserved for future extension */
    unused15    = 0x8000    /* Reserved for future extension */
};

typedef struct
{
    TAddress    PktOrig;      /* The node who created this packet */
    TAddress    PktDest;      /* The node who should receive this packet */
    Word        SubTupe;      /* Packet contents */
    Word        PktType;      /* Always 3 */
    TTimeStamp  PktDate;      /* When the packet was created */
    Word        ProdCode;     /* FTSC Product Code */
    Byte        MajorVer;     /* Major product version */
    Byte        MinorVer;     /* Minor product version */
    Byte        Org[16];      /* Organization */
	CapabilityWord	CapWord;  /* Capability Word */
    Byte        Password[8];  /* Packet password */
    Byte        ExtraInfo[4]; /* Reserved for future extension */
} Type3PKTheader;

typedef struct
{
    TAddress    MsgOrig;      /* The node who created this message */
    TAddress    MsgDest;      /* The node who should receive this message */
    TTimeStamp  MsgDate;      /* When the message was created */
    Longword    MsgID;        /* Unique message identifier */
    Longword    ReplyID;      /* Reply linkage information */
    Longword    MsgLength;    /* Length of the message in bytes */
    TMsgFlags   MsgFlags;     /* Message flags */
    Byte        CharSet1;     /* Character set */
    Byte        CharSet2;     /* Character set */
} Type3PackedMSGheader;

typedef struct
{
    TTimeStamp           SRdate;          /* When message was sent/recived */
    TLocalFlags          LocalFlags;      /* Local flags */
    Word                 ReplyTo;         /* Message which this replies */
    Word                 Areply;          /* Message which replies to this */
    Word                 Cost;            /* In the lowest currency unit */
    Type3PackedMSGheader PackedMSGheader; /* Same as packed MSG */
} Type3StoredMSGheader;

typedef struct
{
    Word    LastRead;       /* The last message read */
    Word    HighRead;       /* The highest message read */
    Word    HighWater;      /* High-water mark */
} ControlFileStr;

/* Text attributes */
#define TurnOff     0x03
#define Bold        0x04
#define Italic      0x05
#define Underline   0x06
#define AllCaps     0x17
#define Subscript   0x19
#define Superscript 0x1A
#define Blinking    0x1C
#define Inverted    0x1D
#define Concealed   0x1E
